@@ -1,4 +1,4 @@
-from typing import Any, TypeVar, Union
+from typing import Any, Sequence, TypeVar, Union
 from enum import EnumMeta
 import enum
 import typing
@@ -23,10 +23,14 @@ class Primitive:
         return self.type
 
     def is_subtype(self, other: Type) -> bool:
-        return (isinstance(other, Primitive) and other.type == self.type) or (
-            isinstance(other, Option) and self.is_subtype(other.type)
-        ) or (
-            self.type == "int" and isinstance(other, Primitive) and other.type == "float"
+        return (
+            (isinstance(other, Primitive) and other.type == self.type)
+            or (isinstance(other, Option) and self.is_subtype(other.type))
+            or (
+                self.type == "int"
+                and isinstance(other, Primitive)
+                and other.type == "float"
+            )
         )
 
 
@@ -43,7 +47,6 @@ class List:
         )
 
 
-
 @dataclass(eq=True, frozen=True)
 class Field:
     name: str
@@ -66,10 +69,7 @@ class Enum:
                 k in other.variants and other.variants[k] == v
                 for k, v in self.variants.items()
             )
-        ) or (
-            isinstance(other, Option) and self.is_subtype(other.type)
-        )
-
+        ) or (isinstance(other, Option) and self.is_subtype(other.type))
 
 
 @dataclass(eq=True, frozen=True)
@@ -92,10 +92,10 @@ class Literal:
                 and other.type == "int"
                 and all(isinstance(v, int) for v in self.allowed_values)
             )
-        ) or (
-            isinstance(other, Option) and self.is_subtype(other.type)
-        )
+        ) or (isinstance(other, Option) and self.is_subtype(other.type))
 
+    def __repr__(self) -> str:
+        return "|".join(repr(v) for v in sorted(self.allowed_values))
 
 
 @dataclass(eq=True, frozen=True)
@@ -110,14 +110,27 @@ class Struct:
     def __str__(self) -> str:
         return self.name
 
-    def is_subtype(self, other: Type) -> bool:
-        return isinstance(other, Struct) and all(
-            k in other.fields and other.fields[k].type.is_subtype(self.fields[k].type)
-            for k in self.fields
-        ) or (
-            isinstance(other, Option) and self.is_subtype(other.type)
-        )
+    def find_field(self, path: Sequence[str]) -> typing.Optional[Field]:
+        schema = self
+        for segment in path[:-1]:
+            if segment not in self.fields:
+                return None
+            _schema = schema.fields[segment].type
+            if not isinstance(_schema, Struct):
+                return None
+            schema = _schema
+        return schema.fields.get(path[-1])
 
+    def is_subtype(self, other: Type) -> bool:
+        return (
+            isinstance(other, Struct)
+            and all(
+                k in other.fields
+                and other.fields[k].type.is_subtype(self.fields[k].type)
+                for k in self.fields
+            )
+            or (isinstance(other, Option) and self.is_subtype(other.type))
+        )
 
 
 @dataclass(eq=True, frozen=True)
@@ -136,6 +149,9 @@ class Nothing:
     def is_subtype(self, other: Type) -> bool:
         return True
 
+    def __repr__(self) -> str:
+        return "Nothing"
+
 
 def materialize_type(clz: typing.Type[Any]) -> Type:
     if clz == int:
